==> axum_static_macro-1.0.7.crate: axum_static_macro-1.0.7/src/lib.rs <==
//! This macro takes an argument of a file path and fills out the proper statics.
//! In debug mode, it will read the file live so you can change it without recompiling the program. Note: You must be in the crate root for this to work.
//! It takes three arguments. Function name (this is what you wrap in the axum get handler), file path, and content type.
//! Does not panic in release mode. Debug mode can panic if the file does not exist.
//! ```rust
//! #[tokio::main]
//! async fn main() {
//!     axum_static_macro::static_file!(static, "index.html", "text/html");
//!     // build our application with a single route
//!     let app = axum::Router::new().route("/", axum::routing::get(static));
//!     // run it with hyper on localhost:3000
//!     axum::Server::bind(&"0.0.0.0:3000".parse().unwrap())
//!         .serve(app.into_make_service())
//!         .await
//!         .unwrap();
//! }
//! ```

/// Usage: `static_file!(root, "index.html", "text/html")`
#[macro_export]
macro_rules! static_file {
    ($name:ident, $path:literal, $ctype:literal) => {
        pub async fn $name() -> (axum::http::StatusCode, axum::http::HeaderMap, String) {
            let mut headers = axum::http::HeaderMap::new();
            headers.insert(
                axum::http::header::CONTENT_TYPE,
                axum::http::HeaderValue::from_static($ctype),
            );
            #[cfg(not(debug_assertions))]
            let file = include_str!($path).to_string();
            #[cfg(debug_assertions)]
            let file = tokio::fs::read_to_string(concat!("src/", $path))
                .await
                .expect(concat!("Program is in debug mode and the ", $path, " file was not found!"));
            (axum::http::StatusCode::OK, headers, file)
        }
    };
}

==> axum_static_macro-1.0.8.crate: axum_static_macro-1.0.8/src/lib.rs <==
//! This macro takes an argument of a file path and fills out the proper statics.
//! In debug mode, it will read the file live so you can change it without recompiling the program. Note: You must be in the crate root for this to work.
//! It takes three arguments. Function name (this is what you wrap in the axum get handler), file path, and content type.
//! Does not panic in release mode. Debug mode can panic if the file does not exist.
//! ```rust
//! #[tokio::main]
//! async fn main() {
//!     axum_static_macro::static_file!(static, "index.html", "text/html");
//!     // build our application with a single route
//!     let app = axum::Router::new().route("/", axum::routing::get(static));
//!     // run it with hyper on localhost:3000
//!     axum::Server::bind(&"0.0.0.0:3000".parse().unwrap())
//!         .serve(app.into_make_service())
//!         .await
//!         .unwrap();
//! }
//! ```

/// Usage: `static_file!(root, "index.html", "text/html")`
#[macro_export]
macro_rules! static_file {
    ($name:ident, $path:literal, $ctype:literal) => {
        pub async fn $name() -> (axum::http::StatusCode, axum::http::HeaderMap, Vec<u8>) {
            let mut headers = axum::http::HeaderMap::new();
            headers.insert(
                axum::http::header::CONTENT_TYPE,
                axum::http::HeaderValue::from_static($ctype),
            );
            #[cfg(not(debug_assertions))]
            let file = include_bytes!($path).to_vec();
            #[cfg(debug_assertions)]
            let file = tokio::fs::read(concat!("src/", $path))
                .await
                .expect(concat!("Program is in debug mode and the ", $path, " file was not found!"));
            (axum::http::StatusCode::OK, headers, file)
        }
    };
}
